# Generated by Django 4.0.6 on 2022-11-25 08:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0033_historicalnaturalperson_maiden_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="term",
            name="disabled",
            field=models.BooleanField(
                default=False,
                help_text="Do not allow this term to be selected",
                verbose_name="Disabled",
            ),
        ),
    ]
