# Generated by Django 3.1.7 on 2021-05-22 11:17

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0008_auto_20210323_1456"),
    ]

    operations = [
        migrations.AlterField(
            model_name="relationship",
            name="person_a",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="relationships_to",
                to="core.person",
            ),
        ),
        migrations.AlterField(
            model_name="relationship",
            name="person_b",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="relationships_from",
                to="core.person",
            ),
        ),
    ]
