# Generated by Django 3.2.5 on 2021-10-30 02:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("contributions", "0003_alter_contribution__import"),
    ]

    operations = [
        migrations.AlterField(
            model_name="contribution",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="contributionimport",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
