# Generated by Django 3.1.5 on 2021-03-11 17:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0006_auto_20210312_0016"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicallegalperson",
            name="_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AddField(
            model_name="historicalnaturalperson",
            name="_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AddField(
            model_name="historicalperson",
            name="_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AddField(
            model_name="historicalpersonassociation",
            name="_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AddField(
            model_name="person",
            name="_type",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="core.term",
            ),
        ),
    ]
