# Generated by Django 3.2.5 on 2021-10-18 09:44

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0021_auto_20211007_0932"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="email",
            name="status",
        ),
        migrations.RemoveField(
            model_name="fax",
            name="status",
        ),
        migrations.RemoveField(
            model_name="phone",
            name="status",
        ),
        migrations.RemoveField(
            model_name="postal",
            name="status",
        ),
        migrations.RemoveField(
            model_name="web",
            name="status",
        ),
    ]
