# Generated by Django 3.2.4 on 2021-11-19 12:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mailer_integration", "0012_auto_20211119_0830"),
    ]

    operations = [
        migrations.AddField(
            model_name="mailingpreferences",
            name="latest_sync",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="synchronized_subscription",
                to="mailer_integration.synchronizationresult",
            ),
        ),
    ]
